dtw_loss_functions package — dtw_loss_functions documentation

# dtw_loss_functions package

## dtw_loss_functions

A package for computing DTW-based loss functions for PyTorch models.

### Modules

block_dtw

  Block-wise variant of the Soft DTW loss.

otw

  Optimal Transport Warping loss.

soft_dtw

  Soft Dynamic Time Warping loss. This module is a wrapper for the various implementations of the SoftDTW available online, which are collected in the `soft_dtw_implementations` subpackage.

### Subpackages

soft_dtw_implementations

  Collection of various implementations of the SoftDTW loss available online.

## Subpackages

- SoftDTW Subpackage
  - Authors
  - SoftDTW (Mehran Maghoumi)
    - Authors
    - `SoftDTW`
      - `SoftDTW.normalize`
      - `SoftDTW.gamma`
      - `SoftDTW.bandwidth`
      - `SoftDTW.dist_func`
      - `SoftDTW.forward()`
    - `compute_softdtw()`
    - `compute_softdtw_backward()`
    - `compute_softdtw_backward_cuda()`
    - `compute_softdtw_cuda()`
    - `profile()`
    - `timed_run()`
  - pysdtw normalized
    - Authors
    - `pysdtw_normalized`
      - `pysdtw_normalized.forward()`
  - SoftDTW (Ron Shapira Weber)
    - `SoftDTW`
      - `SoftDTW.forward()`
    - `softdtw()`
    - `softdtw_barycenter()`
    - `softdtw_barycenter_cpu()`
    - Subpackages
      - dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.cuda package
      - dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.utils package
    - Submodules
      - dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.autograd module
      - dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.autograd_xy module
      - dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.barycenters module
      - dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.distances module
      - dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.functional module
      - dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.module module

## Submodules

- Block DTW
  - Authors
  - `block_dtw`
    - `block_dtw.block_size`
    - `block_dtw.block_dtw_naive`
    - `block_dtw.block_dtw_optimized`
    - `block_dtw.forward()`
  - `block_dtw_naive`
    - `block_dtw_naive.forward()`
  - `block_dtw_optimized`
    - `block_dtw_optimized.forward()`
- OTW
  - Authors
  - `otw`
    - `otw.forward()`
  - `otw_distance()`
  - `smooth_l1_loss()`
  - `window_cumsum()`
- Soft DTW
  - Authors
  - `soft_dtw`
    - `soft_dtw.check_implementation()`
    - `soft_dtw.create_sdtw_function()`
    - `soft_dtw.forward()`
    - `soft_dtw.set_implementation()`
    - `soft_dtw.set_sdtw_config()`